---
title: llarp/rpc/rpc_server.hpp

---

# llarp/rpc/rpc_server.hpp



## Namespaces

| Name           |
| -------------- |
| **[llarp](Namespaces/namespacellarp.md)** <br>[crypto.hpp] |
| **[llarp::rpc](Namespaces/namespacellarp_1_1rpc.md)**  |

## Classes

|                | Name           |
| -------------- | -------------- |
| struct | **[llarp::rpc::RPCServer](Classes/structllarp_1_1rpc_1_1RPCServer.md)**  |
| struct | **[llarp::rpc::MessageHandler](Classes/structllarp_1_1rpc_1_1MessageHandler.md)**  |




## Source code

```cpp
#pragma once

#include <string_view>
#include <llarp/config/config.hpp>
#include <oxenmq/oxenmq.h>
#include <oxenmq/address.h>
#include <oxen/log/omq_logger.hpp>


namespace llarp
{
  struct AbstractRouter;
} 


namespace llarp::rpc
{
  using LMQ_ptr = std::shared_ptr<oxenmq::OxenMQ>;

  struct RPCServer
  {
    explicit RPCServer(LMQ_ptr, AbstractRouter&);

    ~RPCServer() = default;

    void
    AddCategories();

  private:

    LMQ_ptr m_LMQ;
    AbstractRouter& const m_Router;
    oxen::log::PubsubLogger log_subs;
    std::unique_ptr<MessageHandler> messager;

  };

  struct MessageHandler
  {
    explicit MessageHandler(AbstractRouter&);

    explicit MessageHandler(AbstractRouter& _r) : m_Router(_r) {};
    
    ~MessageHandler() = default;

    void
    SetMessage(oxenmq::Message& _msg) { msg = _msg; }

    void
    ClearMessage() { msg = nullptr; }

    void
    SendMessageResponse(oxenmq::Message msg);

    void
    SendMessageError();

    template <typename Result_t>
    std::string
    CreateJSONResponse(Result_t result);

    std::string
    CreateJSONError(std::string_view msg);

    oxenmq::Message& msg;
    AbstractRouter& const m_Router;
  }

}  // namespace llarp::rpc
```


-------------------------------

Updated on 2023-01-11 at 19:02:44 +0000
